render_markdown

Function render_markdown 

pub fn render_markdown(
    files: &[(Utf8PathBuf, &str, bool, usize)],
    repo_name: &str,
) -> String
Render a set of packed files in the human-readable markdown format.

Each file produces a level-2 heading with path and metadata, followed by a fenced code block using the detected language from the file extension.